MathJax.Hub.Config({
 "HTML-CSS": {
    availableFonts: ["TeX"],
    preferredFont: "TeX",
    webFont: "TeX",
    imageFont: null
  },
  config: ["MMLorHTML.js"],
  extensions: ["mml2jax.js"],
  jax: ["input/MathML"],
  positionToHash: true,
  messageStyle: "none",
  showMathMenu: false
});

MathJax.Ajax.loadComplete("[MathJax]/config/yelp.js");
